# ἐντελέχεια 【en.te.lé.kʰeː.a】

[![stai-img]][stai-url]
[![halla-img]][halla-url]
[![home-img]][home-url]
[![lecture-img]][lecture-url]
[![research-img]][research-url]
[![playground-img]][playground-url]
<!-- [![stateful-img]][stateful-url]
[![stateful_dnd-img]][stateful-url] -->

[stai-img]: https://img.shields.io/badge/STAI-jeju.ai-blue
[stai-url]: https://stai.jeju.ai
[playground-img]: https://img.shields.io/badge/playground-app_launcher-blue
[playground-url]: https://entelecheia.cloudflareaccess.com
[halla-img]: https://img.shields.io/badge/CHU-halla.ai-blue
[halla-url]: https://halla.ai
[home-img]: https://img.shields.io/badge/home-entelecheia.me-blue
[home-url]: https://entelecheia.me
[course-img]: https://img.shields.io/badge/course-entelecheia.ai-blue
[course-url]: https://course.entelecheia.ai
[lecture-img]: https://img.shields.io/badge/lecture-entelecheia.ai-blue
[lecture-url]: https://lecture.entelecheia.ai
[research-img]: https://img.shields.io/badge/research-entelecheia.ai-blue
[research-url]: https://research.entelecheia.ai
[linkedin-img]: https://img.shields.io/badge/LinkedIn-blue?logo=linkedin
[linkedin-url]: https://www.linkedin.com/in/entelecheia/
[stateful-img]: https://badge.stateful.com/entelecheia/status.svg
[stateful-url]: https://app.stateful.com/status/entelecheia
[stateful_dnd-img]: https://badge.stateful.com/entelecheia/dnd.svg

Coined by Aristotle from ἐντελής (entelḗs, “complete, full, accomplished”) + ἔχειν (ékhein, “have, hold”).

[![GitHub Streak](http://github-readme-streak-stats.entelecheia.me/?user=entelecheia&theme=transparent&hide_border=true)](https://entelecheia.me/repositories/) 
<!-- [![entelecheia's wakatime stats](https://github-readme-stats.entelecheia.me/api/wakatime?username=entelecheia&layout=compact&theme=transparent&hide_border=true&hide=other,browsing,shell,writing,reviewing,searching,researching,github,ai,text)](https://wakatime.com/@entelecheia) -->

[![entelecheia's github activity graph](https://github-readme-activity-graph.entelecheia.me/graph?username=entelecheia&theme=react-dark&area=true&hide_border=true)](https://entelecheia.me/repositories/)

[![trophy](https://github-profile-trophy.entelecheia.me/?username=entelecheia&theme=darkhub&rank=-C,-B&column=-1&no-bg=true&no-frame=true)](https://entelecheia.me/repositories/)


<a href="https://www.quine.sh/user/entelecheia">
  <img width=49% align="center" src="https://stats.quine.sh/entelecheia/topics-over-time?theme=dark" />
</a>
<a href="https://www.quine.sh/user/entelecheia">
  <img width=49% align="center" src="https://stats.quine.sh/entelecheia/languages-over-time?theme=dark" />
</a>
